@@ -18,6 +18,12 @@ has 'content' => (
     required => 1,
 );
 
+has 'redirects' => (
+    is       => 'ro',
+    isa      => 'Maybe[ArrayRef]',
+    required => 0,
+);
+
 has 'successful' => (
     is       => 'ro',
     isa      => 'Bool',
@@ -43,6 +49,7 @@ has 'content_types' => (
             'text/plain'        => 'Plaintext',
             'text/xml'          => 'XML',
             'application/xml'   => 'XML',
+            'application/pdf'   => 'PDF',
         }
     },
 );
@@ -64,6 +71,13 @@ sub get_image_uris { ... }
 
 sub get_headings { ... }
 
+sub get_images { ... }
+
+sub has_redirects {
+    my ($self) = @_;
+    return (@{ $self->redirects } > 0 ? 1 : 0);
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
