@@ -4,7 +4,6 @@ use common::sense;
 
 use Moose;
 
-use File::Slurper qw(write_binary);
 use Test::LongString qw//;
 
 use overload
@@ -52,12 +51,4 @@ sub lacks_regex {
     return Test::LongString::unlike_string($self->data, $regex, $description);
 }
 
-sub write_to {
-    my ($self, $path) = @_;
-
-    write_binary($path, $self->data);
-
-    return;
-}
-
 1;
